import React, { useContext, useState } from "react";
import { Grid } from "@mui/material";
import { styled } from "@mui/material/styles";
import { RootContainer } from "../../components/common/Container/RootContainer";
import { useParams } from "react-router-dom";
import { useUserInfo } from "../../api/SwaggerApi";
import { userContext } from "@ess-ics/ce-ui-common/dist/contexts/User";
import { UserProfile } from "../../components/common/User/UserProfile";
import { useEffect } from "react";
import { UserIocList } from "../../components/common/User/UserIOCList";
import { UserOperationList } from "../../components/common/User/UserOperationList";

const PREFIX = "UserPage";

const classes = {
  paper: `${PREFIX}-paper`
};

const StyledRootContainer = styled(RootContainer)(({ theme }) => ({
  [`& .${classes.paper}`]: {
    maxWidth: "80%",
    padding: theme.spacing(4)
  }
}));

export function UserPageView() {
  const { userName } = useParams();
  const { user } = useContext(userContext);
  const [errorMessage, setErrorMessage] = useState();

  const [userInfo, getUserInfo, ,] = useUserInfo(userName, (m, s) => {
    // log error message for userInfo
    console.warn(m);
    // user not found
    if (s === 404) {
      setErrorMessage("User not found!");
      // do not show snackbar error
      return false;
    }

    // user doesn't have permission to fetch userInfo
    if (s === 401) {
      setErrorMessage("No activity");
      // do not show snackbar error
      return false;
    }
    // show any other errors with snackbar
  });

  useEffect(() => {
    // user logs in => clear error message, and try to re-request userInfo
    if (user) {
      setErrorMessage(null);
    } else {
      // user is not logged in => show a message
      setErrorMessage("No activity!");
    }
  }, [user]);

  useEffect(() => {
    // request userInfo only if user is logged in
    if (user) {
      getUserInfo();
    }
  }, [getUserInfo, userName, user]);

  // content for userActivity, e.g. operations that the user done, or IOCs that owns
  const userActivityContent = (
    <>
      <Grid
        item
        xs={12}
      >
        <UserOperationList userName={userName} />
      </Grid>

      <Grid
        item
        xs={12}
      >
        <UserIocList userName={userName} />
      </Grid>
    </>
  );

  // show userPage for everyone, but hide userActivity for non-logged in users, and for not existing user
  const content = (
    <>
      <Grid
        item
        xs={12}
      >
        <UserProfile
          userInfo={userInfo}
          errorMessage={errorMessage}
        />
      </Grid>

      {user && !errorMessage && userActivityContent}
    </>
  );

  return (
    <StyledRootContainer>
      <Grid
        container
        spacing={1}
      >
        {content}
      </Grid>
    </StyledRootContainer>
  );
}
