import { Grid, Box, Typography } from "@mui/material";
import React, { useContext, useEffect } from "react";
import { KeyValueTable } from "../../components/common/KeyValueTable/KeyValueTable";
import { IOCAsyncList } from "../../components/IOC/IOCAsyncList";
import { SimpleAccordion } from "../../components/common/Accordion/SimpleAccordion";
import {
  useAnnouncements,
  usePersonalStatistics,
  useOwnIocsWithAlarms
} from "../../api/SwaggerApi";
import ReactMarkdown from "react-markdown";
import { GlobalAppBarContext } from "@ess-ics/ce-ui-common";
import { applicationTitle } from "../../components/common/Helper";
import { RootPaper } from "@ess-ics/ce-ui-common";

export function HomeView() {
  const [announcements] = useAnnouncements();
  const [statistics] = usePersonalStatistics();
  const [
    iocsWithAlarms /* getIocsWithAlarms*/ /* resetResponse*/,
    ,
    ,
    loading
  ] = useOwnIocsWithAlarms();

  const { setTitle } = useContext(GlobalAppBarContext);
  useEffect(() => setTitle(applicationTitle("Home")), [setTitle]);

  return (
    <RootPaper>
      <Grid
        container
        spacing={1}
      >
        <Grid
          item
          xs={10}
        >
          <Box
            display="flex"
            flexDirection="row"
            p={2}
            m={1}
          >
            <Typography variant="h2">Account overview</Typography>
          </Box>
        </Grid>
        {statistics && (
          <Grid
            item
            xs={12}
          >
            <KeyValueTable
              obj={{
                "IOCs registered": statistics.numberOfActiveIocs,
                "IOCs with issues": iocsWithAlarms.length
              }}
              variant="table"
            />
          </Grid>
        )}
        <Grid
          item
          xs={12}
        >
          <SimpleAccordion
            summary="IOCs with issues"
            defaultExpanded
          >
            <IOCAsyncList
              iocs={iocsWithAlarms}
              asyncDetails={false}
              rowType="own"
              loading={loading}
            />
          </SimpleAccordion>
        </Grid>
      </Grid>
      {announcements?.announcementsText && (
        <Grid
          container
          justifyContent="flex-start"
          sx={{ paddingX: 2 }}
        >
          <Grid
            item
            xs={12}
          >
            <ReactMarkdown>{announcements.announcementsText}</ReactMarkdown>
          </Grid>
        </Grid>
      )}
    </RootPaper>
  );
}
