import React, { useEffect, useCallback, useState, useContext } from "react";
import { useRecord } from "../../api/SwaggerApi";
import {
  Paper,
  IconButton,
  Typography,
  LinearProgress,
  Link as MuiLink
} from "@mui/material";
import { Link as ReactRouterLink } from "react-router-dom";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ArrowBackIcon from "@mui/icons-material/ArrowBack";
import { GlobalAppBarContext } from "@ess-ics/ce-ui-common";
import { SimpleAccordion } from "../../components/common/Accordion/SimpleAccordion";
import { KeyValueTable } from "../../components/common/KeyValueTable/KeyValueTable";
import { RecordBadge } from "../../components/records/RecordBadge";
import { applicationTitle, formatDate } from "../../components/common/Helper";
import { useParams } from "react-router-dom";
import { useNavigate } from "react-router-dom";
import { onFetchEntityError } from "../../components/common/Helper";
import NotFoundView from "../../components/navigation/NotFoundView/NotFoundView";

export function RecordDetailsView() {
  const { name } = useParams();
  const decodedName = decodeURIComponent(name);
  const [notFoundError, setNotFoundError] = useState();
  const [record /* getRecord*/ /* reset*/, , , recordLoading] = useRecord(
    decodedName,
    (m, s) => {
      // handle error code 404, and define custom message on the UI because BE sends back generic error message
      onFetchEntityError(m, s, setNotFoundError);
    }
  );
  const navigate = useNavigate();

  const { setTitle } = useContext(GlobalAppBarContext);

  useEffect(() => {
    if (record) {
      setTitle(applicationTitle(`Record Details: ${record.name}`));
    }
  }, [setTitle, record]);

  const handleClick = (event) => {
    navigate(-1);
  };

  const getSubset = useCallback((record) => {
    let subset = {
      IOC: record.iocId ? (
        <Typography>
          <MuiLink
            component={ReactRouterLink}
            to={`/iocs/${record.iocId}`}
            underline="hover"
          >
            {record?.iocName}
          </MuiLink>
        </Typography>
      ) : (
        record?.iocName
      ),
      Description: record?.description,
      Version: record?.iocVersion,
      Host: record.hostCSentryId ? (
        <Typography>
          <MuiLink
            component={ReactRouterLink}
            to={`/hosts/${record.hostCSentryId}`}
            underline="hover"
          >
            {record?.hostName}
          </MuiLink>
        </Typography>
      ) : (
        record?.hostName
      )
    };

    for (const [key, value] of Object.entries(record.properties)) {
      if (key.toLowerCase().includes("time")) {
        subset["Last updated"] = formatDate(value);
      } else if (key.toLowerCase() !== "iocid") {
        subset[key.replaceAll("_", " ")] = value;
      }
    }

    return subset;
  }, []);

  return (
    <RootContainer>
      {notFoundError ? (
        <NotFoundView />
      ) : recordLoading ? (
        <LinearProgress color="primary" />
      ) : (
        <Paper>
          <IconButton
            color="inherit"
            onClick={handleClick}
            size="large"
          >
            <ArrowBackIcon />
          </IconButton>
          {record && (
            <SimpleAccordion
              defaultExpanded
              summary={<RecordBadge record={record} />}
            >
              <KeyValueTable
                obj={getSubset(record)}
                variant="overline"
              />
            </SimpleAccordion>
          )}
        </Paper>
      )}
    </RootContainer>
  );
}
